@@ -1,17 +1,18 @@
-# simulated data to use 
+# simulated data to use
 set.seed(10)
 ds <- data.frame(
   ftime = rexp(200),
-  fstatus = sample(0:1,200,replace=TRUE),
+  fstatus = sample(0:1, 200, replace = TRUE),
   x1 = runif(200),
   x2 = runif(200),
-  x3 = runif(200))
+  x3 = runif(200)
+)
 
 library(rms)
 dd <- datadist(ds)
-options(datadist="dd")
+options(datadist = "dd")
 
 s <- Surv(ds$ftime, ds$fstatus == 1)
-fit <- cph(s ~ x1 + x2 + x3, data=ds)
+fit <- cph(s ~ x1 + x2 + x3, data = ds)
 
-getCphRegrObjData(fit)
+getCphRegrObjData(fit)
\ No newline at end of file
