@@ -1,21 +1,18 @@
 library(testthat)
 
+library(tidyverse)
 set.seed(10)
-n <- 200
-cov <- data.frame(
-  ftime = rexp(n),
-  fstatus = sample(0:1, n, replace = TRUE),
-  x1 = runif(200),
-  x2 = runif(200),
-  x3 = runif(200),
-  x_factor = sample(LETTERS[1:4], n, replace = TRUE)
-)
+cov <- tibble(ftime = rexp(200)) |> 
+  mutate(fstatus = sample(0:1, n(), replace = TRUE),
+         x1 = runif(n()),
+         x2 = runif(n()),
+         x3 = runif(n()),
+         x_factor = sample(LETTERS[1:4], n(), replace = TRUE))
 
 library(rms)
 ddist <<- datadist(cov)
 options(datadist = "ddist")
 
-context("Check fortestplotCombineRegrObj")
 test_that("Check regular lm", {
   # TODO: Add tests - current code is only for coverage reasons
 
@@ -41,13 +38,13 @@ test_that("Check regular lm", {
     return(x)
   }
 
-  forestplotCombineRegrObj(
+  ret <- forestplotCombineRegrObj(
     regr.obj = list(fit1, fit2),
     variablesOfInterest.regexp = "(x2|x3)",
     reference.names = c("First model", "Second model"),
-    rowname.fn = modifyNameFunction,
-    new_page = TRUE
-  )
+    rowname.fn = modifyNameFunction)
+  
+  expect_equal(dim(ret$estimates), c(5, 3, 1))
 })
 
 test_that("Test getModelData4Forestplot", {
@@ -64,39 +61,36 @@ test_that("Test getModelData4Forestplot", {
     regr.obj = list(fit1, fit2),
     exp = TRUE,
     variablesOfInterest.regexp = "(x2|x3)",
-    ref_labels = FALSE,
     add_first_as_ref = FALSE
   )
-  expect_equivalent(
-    data[[1]]["x2", "beta"],
+  expect_equal(
+    data |> filter(column_term == "x2") |> pluck("estimate"),
     exp(coef(fit1)["x2"])
   )
   expect_equivalent(
-    data[[2]]["x3", "beta"],
+    data |> filter(column_term == "x3") |> pluck("estimate"),
     exp(coef(fit2)["x3"])
   )
-  expect_false("x1" %in% rownames(data[[1]]))
-  expect_false("x1" %in% rownames(data[[2]]))
-
+  expect_false("x1" %in% data$column_term)
+  expect_length(unique(data$model_id), 2)
+  
   data <- getModelData4Forestplot(
     regr.obj = list(fit1, fit2),
     exp = TRUE,
     variablesOfInterest.regexp = "(x1)",
-    ref_labels = FALSE,
     add_first_as_ref = FALSE
   )
   expect_equivalent(
-    data[[1]]["x1", "beta"],
+    data |> filter(column_term == "x1" & model_id == "Model 1") |> pluck("estimate"),
     exp(coef(fit1)["x1"])
   )
   expect_equivalent(
-    data[[2]]["x1", "beta"],
+    data |> filter(column_term == "x1" & model_id == "Model 2") |> pluck("estimate"),
     exp(coef(fit2)["x1"])
   )
-  expect_true("x1" %in% rownames(data[[1]]))
-  expect_true("x1" %in% rownames(data[[2]]))
-
-
+  expect_true("x1" %in% data$column_term)
+  expect_false("x2" %in% data$column_term)
+  
   fit3 <- cph(Surv(ftime, fstatus) ~ x1 + x2 + x_factor, data = cov)
   fit4 <- cph(Surv(ftime, fstatus) ~ x1 + x3 + x_factor, data = cov)
 
@@ -104,51 +98,59 @@ test_that("Test getModelData4Forestplot", {
     regr.obj = list(fit3, fit4),
     exp = TRUE,
     variablesOfInterest.regexp = "(x1|x_factor)",
-    ref_labels = FALSE,
     add_first_as_ref = FALSE
   )
   expect_equivalent(
-    data[[1]]["x1", "beta"],
+    data |> filter(column_term == "x1" & model_id == "Model 1") |> pluck("estimate"),
     exp(coef(fit3)["x1"])
   )
   expect_equivalent(
-    data[[2]]["x1", "beta"],
+    data |> filter(column_term == "x1" & model_id == "Model 2") |> pluck("estimate"),
     exp(coef(fit4)["x1"])
   )
   expect_equivalent(
-    data[[1]]["x_factor=B", "beta"],
+    data |> filter(column_term == "x_factor" & 
+                     factor == "B" &
+                     model_id == "Model 1") |> 
+      pluck("estimate"),
     exp(coef(fit3)["x_factor=B"])
   )
   expect_equivalent(
-    data[[2]]["x_factor=C", "beta"],
+    data |> filter(column_term == "x_factor" & 
+                     factor == "C" &
+                     model_id == "Model 2") |> 
+      pluck("estimate"),
     exp(coef(fit4)["x_factor=C"])
   )
-  expect_true("x1" %in% rownames(data[[1]]))
-  expect_true("x1" %in% rownames(data[[2]]))
-  expect_false("x2" %in% rownames(data[[1]]))
-  expect_false("x2" %in% rownames(data[[2]]))
+  expect_true("x1" %in% data$column_term)
+  expect_false("x2" %in% data$column_term)
   expect_equivalent(
-    nrow(data[[1]]),
-    4
+    data |> filter(model_id == "Model 1") |> nrow(),
+    4 + 1
   )
   expect_equivalent(
-    nrow(data[[2]]),
-    4
+    data |> filter(model_id == "Model 2") |> nrow(),
+    4 + 1
   )
 
   data <- getModelData4Forestplot(
     regr.obj = list(fit3, fit4),
     exp = TRUE,
     variablesOfInterest.regexp = "(x_factor)",
-    ref_labels = "x_factor=A",
     add_first_as_ref = TRUE
   )
   expect_equivalent(
-    data[[1]][1, "beta"],
+    data |> 
+      filter(model_id == "Model 1") |>  
+      filter(row_number() == 2) |> 
+      pluck("estimate"),
     1
   )
   expect_equivalent(
-    data[[2]][1, "beta"],
+    data |> 
+      filter(model_id == "Model 2") |> 
+      filter(row_number() == 2) |> 
+      pluck("estimate"),
     1
   )
 
@@ -156,24 +158,37 @@ test_that("Test getModelData4Forestplot", {
     regr.obj = list(m1 = fit3, m2 = fit4),
     exp = FALSE,
     variablesOfInterest.regexp = "(x_factor)",
-    ref_labels = "x_factor=A",
     add_first_as_ref = TRUE
   )
   expect_equivalent(
-    data[[1]][1, "beta"],
+    data |> 
+      filter(model_id == "m1") |> 
+      filter(row_number() == 2) |> 
+      pluck("estimate"),
     0
   )
   expect_equivalent(
-    data[[2]][1, "beta"],
+    data |> 
+      filter(model_id == "m2") |> 
+      filter(row_number() == 2) |> 
+      pluck("estimate"),
     0
   )
 
   expect_equivalent(
-    data[[1]]["x_factor=B", "beta"],
+    data |> 
+      filter(model_id == "m1" & 
+               column_term == "x_factor" & 
+               factor == "B") |> 
+      pluck("estimate"),
     coef(fit3)["x_factor=B"]
   )
   expect_equivalent(
-    data[[2]]["x_factor=C", "beta"],
+    data |> 
+      filter(model_id == "m2" & 
+               column_term == "x_factor" & 
+               factor == "C") |> 
+      pluck("estimate"),
     coef(fit4)["x_factor=C"]
   )
 })
